@@ -1,11 +1,13 @@
 import inspect
+
 import sheraf
-from sheraf.models.indexation import BaseIndexedModel
 from sheraf.attributes import Attribute
-from sheraf.attributes.collections import ListAttribute, SetAttribute
+from sheraf.attributes.collections import ListAttribute
+from sheraf.attributes.collections import SetAttribute
+from sheraf.models.indexation import BaseIndexedModel
 
 
-class ModelLoader(object):
+class ModelLoader:
     """
     Loads models from the base in a cache.
 
@@ -75,7 +77,7 @@ class ModelLoader(object):
 
         elif parent and not isinstance(model, type):
             return type(
-                "{}.{}".format(parent.__class__.__name__, self.key(parent)),
+                f"{parent.__class__.__name__}.{self.key(parent)}",
                 (model.__class__,),
                 model.attributes,
             )
@@ -99,17 +101,17 @@ class AttributeLoader(ModelLoader):
         if isinstance(attribute, (ListAttribute, SetAttribute)):
             if not isinstance(attribute.attribute, ModelAttribute):
                 raise sheraf.SherafException(
-                    f"'{self._model.__name__}.{attribute}' attribute should hold a 'ModelAttribute' to be referenced by a 'ReverseModelAttribute'"
+                    f"'{self._model.__name__}.{attribute_name}' attribute should hold a 'ModelAttribute' to be referenced by a 'ReverseModelAttribute'"
                 )
 
         elif not isinstance(attribute, ModelAttribute):
             raise sheraf.SherafException(
-                f"'{self._model.__name__}.{attribute}' should be a 'ModelAttribute' or a collection of 'ModelAttribute' to be referenced by a 'ReversedModelAttribute'"
+                f"'{self._model.__name__}.{attribute_name}' should be a 'ModelAttribute' or a collection of 'ModelAttribute' to be referenced by a 'ReversedModelAttribute'"
             )
 
         if attribute_name not in self.model.indexes:
             raise sheraf.SherafException(
-                f"'{self._model.__name__}.{attribute}' should have an index to be referenced by a 'ReversedModelAttribute'"
+                f"'{self._model.__name__}.{attribute_name}' should have an index to be referenced by a 'ReversedModelAttribute'"
             )
 
 
