@@ -1,12 +1,13 @@
 import itertools
 
 from BTrees.OOBTree import OOBTree
-from ..types import SmallDict
 from sheraf.databases import Database
 from sheraf.exceptions import NoDatabaseConnectionException
 from sheraf.exceptions import NotConnectedException
 from sheraf.exceptions import UniqueIndexException
 
+from ..types import SmallDict
+
 
 def setdefault(table, key, alternative):
     try:
@@ -161,7 +162,7 @@ class IndexManager:
             index_container.append(value)
 
     def _root_check(self):
-        if all((not table for table in self.root().values())):
+        if all(not table for table in self.root().values()):
             self.delete_root()
 
 
@@ -187,10 +188,7 @@ class SimpleIndexManager(IndexManager):
         return setdefault(self.persistent, self.details.key, self.details.mapping)
 
     def _get_item(self, key, silent_errors=False):
-        try:
-            return self.persistent[self.details.key][key]
-        except KeyError:
-            return None
+        return self.persistent[self.details.key][key]
 
     def has_item(self, key):
         return self.persistent[self.details.key].has_key(key)
